@@ -5,7 +5,7 @@
                          File: command-top.lisp
 ==============================================================================|#
 ;;;
-;;; Copyright (c) 2000-2015, Toshimi Sawada. All rights reserved.
+;;; Copyright (c) 2000-2017, Toshimi Sawada. All rights reserved.
 ;;;
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -97,6 +97,9 @@
                             #+CMU
                             (("-core")
                              (incf i 2)) ; ignore this
+                            (("-dev")
+                             (setq *development-mode* t)
+                             (incf i))
                             (("-debug")
                              (on-debug)
                              (incf i))
