@@ -96,7 +96,34 @@
   `(the #-GCL simple-vector #+GCL vector (caddr ,?+_v)))
 (defmacro match-equation-comp-comp (v__?)
   `(the #-GCL simple-vector #+GCL vector (cadddr ,v__?)))
-  
+
+;;; Modifies the array "sys" of "match-equation-comp" in such a way that
+;;; all the comp array are reset provide that they rank in "sys"
+;;; is less (strictly) than K.
+;;;
+;;; Reset the comp of "eq-comp" to his initial value i.e. (1,2,3,4,5)
+;;;
+(declaim (inline match-a-reset-comp))
+(defun match-A-reset-comp (eq-comp)
+  (declare (type list eq-comp)
+           (optimize (speed 3) (safety 0)))
+  (let ((comp (match-equation-comp-comp eq-comp)))
+    (declare (type #+GCL vector #-GCL simple-vector comp))
+    (dotimes (x (1- (match-equation-comp-sz-left eq-comp)))
+      (declare (type fixnum x))
+      (setf (aref comp x) (1+ x)))))
+
+
+(declaim (inline match-a-reset-match-equation-comp))
+
+(defun match-A-reset-match-equation-comp (sys K)
+  (declare (type #+GCL vector #-GCL simple-vector sys)
+           (type fixnum k)
+           (optimize (speed 3) (safety 0)))
+  (dotimes (i K)                                ; i = 0,...,K-1 
+    (declare (type fixnum i))
+    (match-A-reset-comp (svref sys i))))
+
 (defun print-equation-comp (e-c)
   (princ "[equation-comp size left: ") (prin1 (match-equation-comp-sz-left e-c))
   (print-next)
@@ -110,6 +137,37 @@
   (princ "]")
   )
 
+;;; Try to increase with respect with the lexicographical order
+;;; on the arrays of integer the integer array "comp". These are
+;;; the following constaints:
+;;; 1) the elements of the array are all different and ordered in 
+;;; increasing order: example (2 3 4 6 8)
+;;; 2) the grastest element of the array in LESS OR EQUAL to "max"
+;;; Returns true iff one have succeded to increment.
+;;;
+(declaim (inline match-a-try-increase-lexico))
+
+(defun match-A-try-increase-lexico (comp max)
+  (declare (type fixnum max)
+           (type #+GCL vector #-GCL simple-vector comp)
+           (optimize (speed 3) (safety 0)))
+  (let ((lim (1- (the fixnum (length comp)))))
+    (declare (type fixnum lim))
+    (do ((i lim (- i 1)))
+        ((< i 0) nil)
+      (declare (type fixnum i))
+      (let ((x (svref comp i)))
+        (declare (type fixnum x))
+        (when (< x max)
+          (setf (svref comp i) (1+ x))
+          (do ((j (1+ i) (1+ j))
+               (v (+ x 2) (1+ v)))
+              ((< lim j))
+            (declare (type fixnum j v))
+            (setf (svref comp j) v))
+          (return t)))
+      (setq max (1- max)))))
+
 ;;; Simplify the left symbols and the right symbols. Returns the modified list
 ;;; of terms.  
 ;;; EXAMPLE: (a,x,c,z,d,c) == (a,b,b,b,c,c,c,c) is simplified into
@@ -120,11 +178,10 @@
 ;;;
 (declaim (inline match-associative-simplify))
 
-(#-GCL defun #+GCL si:define-inline-function
-       match-associative-simplify (sub1 sub2)
+(defun match-associative-simplify (sub1 sub2)
   (declare (type list sub1 sub2)
+           (optimize (speed 3) (safety 0))
            (values (or null t)))
-  ;;
   (do ((t1 (car sub1) (car sub1))
        (t2 (car sub2) (car sub2)))
       ((or (null sub1)
@@ -170,9 +227,9 @@
 
 (declaim (inline match-associativity-set-eq-state))
          
-(#-GCL defun #+GCL si:define-inline-function
-       match-associativity-set-eq-state (sub1 sub2)
-  (declare (type list sub1 sub2))
+(defun match-associativity-set-eq-state (sub1 sub2)
+  (declare (type list sub1 sub2)
+           (optimize (speed 3) (safety 0)))
   (let* ((sz1 (length sub1))
          (comp (alloc-svec-fixnum (if (= 0 sz1) 0 (- sz1 1)))))
     (declare (type #+GCL vector #-GCL simple-vector comp)
@@ -191,10 +248,10 @@
 ;;;
 (declaim (inline match-a-make-term))
 
-(#-GCL defun #+GCL si:define-inline-function
-       match-A-make-term (method vect first last)
+(defun  match-A-make-term (method vect first last)
   (declare (type fixnum first last)
-           (type #+GCL vector #-GCL simple-vector vect))
+           (type #+GCL vector #-GCL simple-vector vect)
+           (optimize (speed 3) (safety 0)))
   (if (= first last)
       (svref vect first)
     (let ((res (svref vect last)))
@@ -218,10 +275,10 @@
 ;;;
 (declaim (inline match-a-extract-in-from-to))
 
-(#-GCL defun #+GCL si:define-inline-function
-       match-A-extract-in-from-to (t-arr from to)
+(defun match-A-extract-in-from-to (t-arr from to)
   (declare (type fixnum from to)
-           (type #+GCL vector #-GCL simple-vector t-arr))
+           (type #+GCL vector #-GCL simple-vector t-arr)
+           (optimize (speed 3) (safety 0)))
   (let ((t-list nil))
     (do ((i to (1- i)))
         ((< i from)  t-list)
@@ -233,8 +290,9 @@
 ;;;
 (declaim (inline increment-the-match-a-state))
 
-(#-GCL defun #+GCL si:define-inline-function
-       increment-the-match-A-state (A-st)
+(defun increment-the-match-A-state (A-st)
+  (declare (type match-a-state A-st)
+           (optimize (speed 3) (safety 0)))
   (block the-end
     (let ((sz (match-A-state-size A-st))
           (sys (match-A-state-sys A-st)))
@@ -263,63 +321,6 @@
       (setf (match-A-state-no-more A-st) t)
       )))
 
-;;; Try to increase with respect with the lexicographical order
-;;; on the arrays of integer the integer array "comp". These are
-;;; the following constaints:
-;;; 1) the elements of the array are all different and ordered in 
-;;; increasing order: example (2 3 4 6 8)
-;;; 2) the grastest element of the array in LESS OR EQUAL to "max"
-;;; Returns true iff one have succeded to increment.
-;;;
-(declaim (inline match-a-try-increase-lexico))
-
-(#-GCL defun #+GCL si:define-inline-function
-       match-A-try-increase-lexico (comp max)
-  (declare (type fixnum max)
-           (type #+GCL vector #-GCL simple-vector comp))
-  (let ((lim (1- (length comp))))
-    (declare (type fixnum lim))
-    (do ((i lim (- i 1)))
-        ((< i 0) nil)
-      (declare (type fixnum i))
-      (let ((x (svref comp i)))
-        (declare (type fixnum x))
-        (when (< x max)
-          (setf (svref comp i) (1+ x))
-          (do ((j (1+ i) (1+ j))
-               (v (+ x 2) (1+ v)))
-              ((< lim j))
-            (declare (type fixnum j v))
-            (setf (svref comp j) v))
-          (return t)))
-      (setq max (1- max)))))
-
-;;; Reset the comp of "eq-comp" to his initial value i.e. (1,2,3,4,5)
-;;;
-(declaim (inline match-a-reset-comp))
-
-(#-GCL defun #+GCL si:define-inline-function
-       match-A-reset-comp (eq-comp)
-  (let ((comp (match-equation-comp-comp eq-comp)))
-    (declare (type #+GCL vector #-GCL simple-vector comp))
-    (dotimes (x (1- (match-equation-comp-sz-left eq-comp)))
-      (declare (type fixnum x))
-      (setf (aref comp x) (1+ x)))))
-
-;;; Modifies the array "sys" of "match-equation-comp" in such a way that
-;;; all the comp array are reset provide that they rank in "sys"
-;;; is less (strictly) than K.
-;;;
-(declaim (inline match-a-reset-match-equation-comp))
-
-(#-GCL defun #+GCL si:define-inline-function
-       match-A-reset-match-equation-comp (sys K)
-  (declare (type #+GCL vector #-GCL simple-vector sys)
-           (type fixnum k))
-  (dotimes (i K)                                ; i = 0,...,K-1 
-    (declare (type fixnum i))
-    (match-A-reset-comp (svref sys i))))
-
 
 ;;; A-STATE Initialization -----------------------------------------------------
 
