@@ -486,11 +486,11 @@
                                 *bool-true*))
                   (error-p nil))
              (setf sort (term-sort parsed-lhs))
-             (when (and parsed-cnd (term-ill-defined parsed-cnd))
+             (when (and parsed-cnd (term-is-an-error parsed-cnd))
                (with-output-simple-msg ()
                  (princ "[Error] no parse for condition part of the axiom."))
                (setf error-p t))
-             (if (or (term-ill-defined parsed-lhs)
+             (if (or (term-is-an-error parsed-lhs)
                      (null sort))
                  (with-output-chaos-error ('invalid-lhs)
                    (princ "no parse for LHS of the axiom (ignored): "))
@@ -525,7 +525,7 @@
                                   *bool-true*))
                     (error-p nil))
                ;; check condition part.
-               (when (and cond-part (term-ill-defined parsed-cnd))
+               (when (and cond-part (term-is-an-error parsed-cnd))
                  (with-output-simple-msg ()
                    (princ "[Error] no parse for axiom condition"))
                  (setf error-p t))
@@ -710,12 +710,12 @@
     (let ((*parse-variables* nil)
           (*macroexpand* nil))
       (setq lhs (simple-parse *current-module* pre-lhs *cosmos*))
-      (when (term-ill-defined lhs)
+      (when (term-is-an-error lhs)
         (with-output-chaos-error ('invalid-macro-lhs)
           (format t "no parse for LHS of the macro declaration: ")
           (print-chaos-object ast)))
       (setq rhs (simple-parse *current-module* pre-rhs *cosmos*))
-      (when (term-ill-defined rhs)
+      (when (term-is-an-error rhs)
         (with-output-chaos-error ('invalid-macro-rhs)
           (format t "no parse for RHS of the macro declaration: ")
           (print-chaos-object ast)))
