@@ -1067,6 +1067,58 @@
       (append (module-own-axioms-ordered mod)
               (module-imported-axioms mod no-system-equations))))
 
+;;;
+;;; SYMBOL TABLE Functions
+;;;
+(defun canonicalize-object-name (nm)
+  (declare (optimize (speed 3) (safety 0)))
+  (cond ((stringp nm)
+         (intern nm))
+        ((consp nm)
+         (if (cdr nm)
+             (mapcar #'canonicalize-object-name nm)
+           (canonicalize-object-name (car nm))))
+        ((symbolp nm) nm)
+        ((module-p nm) (canonicalize-object-name (module-name nm)))
+        (t
+         ;; do nothing
+         )))
+
+(defun symbol-table-add (table nm obj)
+  (declare (type symbol-table table)
+           (optimize (speed 3) (safety 0)))
+  (when (and (module-p obj)
+             (module-is-parameter-theory (the module obj)))
+    (setq nm (car (module-name obj))))
+  (let ((name (canonicalize-object-name nm)))
+    (pushnew name (symbol-table-names table) :test #'equal)
+    (let* ((map (symbol-table-map table))
+           (tbl (gethash name map)))
+      (unless tbl
+        (setf tbl (setf (gethash name map) (make-stable))))
+      (cond ((sort-p obj)
+             (pushnew obj (stable-sorts tbl)))
+            ((operator-p obj)
+             (pushnew obj (stable-operators tbl)))
+            ((module-p obj)
+             (if (module-is-parameter-theory obj)
+                 (pushnew obj (stable-parameters tbl))
+               (pushnew obj (stable-submodules tbl))))
+            ((axiom-p obj)
+             (pushnew obj (stable-axioms tbl)))
+            ((and (term? obj)
+                  (term-is-variable? obj))
+             (pushnew obj (stable-variables tbl)))
+            (t (pushnew obj (stable-unknowns tbl))))
+      tbl)))
+
+(defun symbol-table-get (name &optional (module (get-context-module)))
+  (declare (type module module)
+           (optimize (speed 3) (safety 0)))
+  (let ((gname (canonicalize-object-name name)))
+    (gethash gname (symbol-table-map
+                    (module-symbol-table module)))))
+
 ;;; EOF
 
 
