@@ -267,36 +267,36 @@ NOTE: this switch is obsolete now. please use `print mode' switch instead."
 (defun show-modes (flg)
   (if (eq flg t)
       (let ((*print-line-limit* 62))
-        (format t "~%switch~24Tvalue~%--------------------------------------------------------------")
+        (format t "~%switch~24Tvalue~%========================================================")
         (dolist (sw *chaos-switches*)
           (unless (chaos-switch-hidden sw)
             (show-mode sw))))
     (let ((sw flg))
       (if (or (equal sw '(".")) (null sw))
           (show-modes t)
-            (let ((which (car flg))
+        (let ((which (car flg))
               (sub (cdr flg))
               (found nil)
               (cand nil))
-              (dolist (sw *chaos-switches*)
+          (dolist (sw *chaos-switches*)
             (block next
               (let ((key (chaos-switch-key sw)))
                 (when (eq key :comment) (return-from next nil))
                 (when (atom key) (setq key (list key)))
                 (when (member which key :test #'equal)
-                  (setq cand sw)
+                  ;; (setq cand sw)
+                  (push sw cand)
                   (let ((opt (chaos-switch-subkey sw)))
                     (when (equal opt (firstn sub (length opt)))
-                      (setq found sw)
-                      (setq cand nil)
-                      (return)))))))
-              (unless (or found cand)
+                      (setq found sw)))))))
+          (unless (or found cand)
             (with-output-chaos-warning ()
               (format t "unknown switch ~a" flg)
               (return-from show-modes nil)))
-              (if found
+          (if found
               (show-mode found)
-            (show-mode cand)))))))
+            (dolist (sw cand)
+              (show-mode sw))))))))
 
 (defun show-mode (switch)
   (let ((name (chaos-switch-key switch))
@@ -306,11 +306,11 @@ NOTE: this switch is obsolete now. please use `print mode' switch instead."
     (cond ((eq name :comment)
            (format t "~%~a" (second switch)))
           ((equal name "libpath")
-           (format t "~%libpath~24T= ~{~a~^:~}" value))
+           (format t "~%libpath~24T ~{~a~^:~}" value))
           (t (when (atom name) (setq name (list name)))
              (if (eq type 'parity)
                  (format t "~%~{~a~^|~a~} ~{~^ ~a~} ~24T~:[off~;on~]" name option value)
-               (progn (format t "~%~{~a~^|~a~} ~{~^ ~a~} ~24T= " name option)
+               (progn (format t "~%~{~a~^|~a~} ~{~^ ~a~} ~24T" name option)
                       (if value
                           (print-chaos-object value)
                         (princ "not specified"))))))))
