@@ -1,7 +1,7 @@
 ;;; cafeobj-mode.el --- CafeOBJ code editing and Interaction with
 ;;;                     CafeOBJ interpreter.
 ;;;
-;;; Copyright (c) 2000-2014, Toshimi Sawada. All rights reserved.
+;;; Copyright (c) 2000-2016, Toshimi Sawada. All rights reserved.
 ;;;
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -409,10 +409,6 @@ This is in addition to cafeobj-continued-statement-offset."
       "ops"
       "sort"
       "hsort"
-;      "["
-;      "]"
-;      "*["
-;      "]*"
       "bop"
       "pred"
       "bops"
@@ -557,16 +553,27 @@ This is in addition to cafeobj-continued-statement-offset."
       ":auto"
       ":ind"
       ":init"
+      ":imp"
       ":cp"
       ":ctf"
+      ":ctf-"
       ":csp"
+      ":csp-"
       ":show"
+      ":sh"
       ":describe"
+      ":desc"
       ":verbose"
       ":backward"
       ":equation"
       ":rule"
       ":select"
+      ":order"
+      ":use"
+      ":embed"
+      ":red"
+      ":define"
+      ":set"
       )
   "CafeOBJ top-level commands")
 
@@ -705,8 +712,9 @@ This is in addition to cafeobj-continued-statement-offset."
 ;;; se use extended abbriv 
 (autoload 'expand-abbrev-hook "expand")
 
-;;; some default abbreviations define here
-(if cafeobj-mode-abbrev-table
+;;; some default abbreviations defined here
+;;; 
+'(if cafeobj-mode-abbrev-table
     nil
   (define-abbrev-table 'cafeobj-mode-abbrev-table
     '(;; top level declaration
